package com.virtual.plat.server.rs.organize;

import com.virtual.common.AppException;
import com.virtual.common.StringManager;
import com.virtual.plat.server.entity.QueryConfig;
import com.virtual.plat.server.rs.RestUtils;
import com.virtual.plat.server.rs.entity.ListResult;
import com.virtual.plat.server.rs.organize.func.RsOrganizeMgr;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import javax.annotation.security.RolesAllowed;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.Consumes;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.SecurityContext;
import javax.ws.rs.core.UriInfo;
import javax.ws.rs.core.Response.ResponseBuilder;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.stereotype.Service;

@Service
@Path("/organize")
@Consumes({"application/xml", "application/json"})
@Produces({"application/xml", "application/json"})
public class RsOrganizeResource {

   private static Log log = LogFactory.getLog(RsOrganizeResource.class);
   private static StringManager sm = StringManager.getManager("com.virtual.plat.server.rs.common");
   @Resource
   private RsOrganizeMgr rsOrganizeMgr;
   @Context
   private UriInfo uriInfo;
   @Context
   private SecurityContext sc;
   @Context
   private HttpServletRequest req;


   @GET
   @Path("/vm")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public Response getOrgVmList() {
      MultivaluedMap var1;
      QueryConfig var2 = RestUtils.queryParamToQueryInfo(var1 = this.uriInfo.getQueryParameters());
      String var3 = this.sc.getUserPrincipal().getName();
      Iterator var4 = var1.keySet().iterator();

      while(var4.hasNext()) {
         String var5 = (String)var4.next();
         if("title".equals(var5)) {
            String var6 = (String)var1.getFirst(var5);
            var2.addRestriction(var5, var6);
         }

         if("orgId".equals(var5)) {
            var2.addRestriction(var5, Long.valueOf((String)var1.getFirst(var5)));
         }
      }

      ResponseBuilder var7;
      ListResult var8;
      (var7 = Response.ok(var8 = this.rsOrganizeMgr.queryVmList(var3, var2))).header("Total", Long.valueOf(var8.getSize()));
      return var7.build();
   }

   @GET
   @Path("/template")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public Response getOrgTmpList() {
      QueryConfig var1 = RestUtils.queryParamToQueryInfo(this.uriInfo.getQueryParameters());
      String var2 = this.sc.getUserPrincipal().getName();
      if(var1.getRestriction("orgId") == null) {
         log.error("orgId is null.");
         throw new AppException(16, new Object[]{sm.getString("org.id.is.null")});
      } else {
         ListResult var3;
         ResponseBuilder var4;
         (var4 = Response.ok(var3 = this.rsOrganizeMgr.queryTmpList(var2, var1))).header("Total", Long.valueOf(var3.getSize()));
         return var4.build();
      }
   }

   @GET
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public Response getOrganizeList() {
      String var1 = this.sc.getUserPrincipal().getName();
      List var2 = this.rsOrganizeMgr.queryOrganizationList(var1);
      return Response.ok(new ListResult(0L, (long)var2.size(), var2)).build();
   }

   @GET
   @Path("/storage/scpToFile")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public void scpToFile(@QueryParam("orgId") Long var1, @QueryParam("srcFile") String var2, @QueryParam("destFile") String var3) {
      if(var1 == null) {
         log.error("orgId is null.");
         throw new AppException(16, new Object[]{sm.getString("org.id.is.null")});
      } else if(var2 == null) {
         log.error("srcFile is null.");
         throw new AppException(16, new Object[]{sm.getString("srcFile.is.null")});
      } else if(var3 == null) {
         log.error("destFile is null.");
         throw new AppException(16, new Object[]{sm.getString("destFile.is.null")});
      } else {
         this.rsOrganizeMgr.scpToFile(var1, var2, var3);
      }
   }

   @GET
   @Path("/storage/scpFromFile")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public void scpFromFile(@QueryParam("orgId") Long var1, @QueryParam("clusterId") Long var2, @QueryParam("srcFile") String var3, @QueryParam("destFile") String var4) {
      if(var1 == null) {
         log.error("orgId is null.");
         throw new AppException(16, new Object[]{sm.getString("org.id.is.null")});
      } else if(var3 == null) {
         log.error("srcFile is null.");
         throw new AppException(16, new Object[]{sm.getString("srcFile.is.null")});
      } else if(var4 == null) {
         log.error("destFile is null.");
         throw new AppException(16, new Object[]{sm.getString("destFile.is.null")});
      } else {
         this.rsOrganizeMgr.scpFromFile(var1, var2, var3, var4);
      }
   }

   @GET
   @Path("/deployrs/{msgId}")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public Response deployResult(@PathParam("msgId") Long var1) {
      return Response.ok(this.rsOrganizeMgr.queryDeployResult(var1)).build();
   }

   @GET
   @Path("/uploadcheck")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public Response checkUpLoadCondition(@QueryParam("orgId") Long var1, @QueryParam("clusterId") Long var2, @QueryParam("storagePoolName") String var3, @QueryParam("storagePoolPath") String var4, @QueryParam("folderName") String var5, @QueryParam("fileName") String var6, @QueryParam("fileSize") Long var7) {
      if(var1 == null) {
         log.error("orgId is null.");
         throw new AppException(16, new Object[]{sm.getString("org.id.is.null")});
      } else if(var3 == null) {
         log.error("storagePoolName is null.");
         throw new AppException(16, new Object[]{sm.getString("storagePoolName.is.null")});
      } else if(var4 == null) {
         log.error("storagePoolPath is null.");
         throw new AppException(16, new Object[]{sm.getString("storagePoolPath.is.null")});
      } else if(var5 == null) {
         log.error("folderName is null.");
         throw new AppException(16, new Object[]{sm.getString("folderName.is.null")});
      } else {
         this.rsOrganizeMgr.checkUpLoadCondition(var1, var2, var3, var4, var5, var6, var7);
         return Response.ok().build();
      }
   }

   @GET
   @Path("/orgList")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public Response getOrgList() {
      QueryConfig var1 = RestUtils.queryParamToQueryInfo(this.uriInfo.getQueryParameters());
      String var2 = this.sc.getUserPrincipal().getName();
      List var3 = this.rsOrganizeMgr.queryOrgList(var2, var1);
      return Response.ok(new ListResult((long)var1.getOffset(), (long)var3.size(), var3)).build();
   }

   @POST
   @Path("/batchDeploy")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public List batchDeployDomain(List var1) {
      if(var1 != null && var1.size() > 0) {
         String var2 = this.sc.getUserPrincipal().getName();
         String var3 = this.req.getRemoteAddr();
         return this.rsOrganizeMgr.batchDeployDomain(var1, var2, var3);
      } else {
         throw new AppException(15);
      }
   }

   @GET
   @Path("/queryByUserName")
   @RolesAllowed({"VMC-PLAT-ROLE_RSCLIENT"})
   public String getVmPreNameByUserName(@QueryParam("userName") String var1) {
      return this.rsOrganizeMgr.getOrgByUserName(var1).getDomainPreName();
   }

}
